pub struct CompoundCondition {
pub left: Option<Box<ConditionExpr>>,
pub op: i32,
pub right: Option<Box<ConditionExpr>>,
}Expand description
Two conditions joined by a logical operator.
Fields
left: Option<Box<ConditionExpr>>op: i32right: Option<Box<ConditionExpr>>Implementations
Sourceimpl CompoundCondition
impl CompoundCondition
Sourcepub fn op(&self) -> LogicalOperator
pub fn op(&self) -> LogicalOperator
Returns the enum value of op, or the default if the field is set to an invalid enum value.
Sourcepub fn set_op(&mut self, value: LogicalOperator)
pub fn set_op(&mut self, value: LogicalOperator)
Sets op to the provided enum value.