pub struct Predicate {
pub left: String,
pub operator: i32,
pub right: String,
}Expand description
Simple comparison predicate.
Fields
left: Stringoperator: i32right: StringImplementations
Sourceimpl Predicate
impl Predicate
Sourcepub fn operator(&self) -> ComparisonOperator
pub fn operator(&self) -> ComparisonOperator
Returns the enum value of operator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operator(&mut self, value: ComparisonOperator)
pub fn set_operator(&mut self, value: ComparisonOperator)
Sets operator to the provided enum value.