pub type WebUIFragmentRecords = HashMap<String, FragmentList>;Expand description
A mapping of unique fragment identifiers to their corresponding fragment lists.
Aliased Type
pub struct WebUIFragmentRecords { /* private fields */ }pub type WebUIFragmentRecords = HashMap<String, FragmentList>;A mapping of unique fragment identifiers to their corresponding fragment lists.
pub struct WebUIFragmentRecords { /* private fields */ }